# QEMU Guest Agent
# 2016-2020 foo.li systeme + software

$packageName	= 'qemu-guest-agent'
$version        = '100.0.0.0'
$installerType	= 'msi'
$url		= 'https://fedorapeople.org/groups/virt/virtio-win/direct-downloads/archive-qemu-ga/qemu-ga-win-' + $version + '-3.el7ev/qemu-ga-x86.msi'
$url64          = 'https://fedorapeople.org/groups/virt/virtio-win/direct-downloads/archive-qemu-ga/qemu-ga-win-' + $version + '-3.el7ev/qemu-ga-x64.msi'
$silentArgs	= '/qb'
$packageSearch	= 'QEMU guest agent*'
$checksum       = '7f298036d0445dc32601e8416bc59e623639d282'
$checksumType	= 'sha1'
$checksum64	= '50cb4a3840665d4ffdff1c0d27a14074165fc501'
$checksumType64 = $checksumType
$validExitCodes	= @(0,3010)

$compmanu = Get-WmiObject Win32_ComputerSystem | select manufacturer
if ($compmanu.manufacturer -like '*Bochs*') { Write-Host 'QEMU/KVM detected' }
elseif ($compmanu.manufacturer -like '*QEMU*'){ Write-Host 'QEMU/KVM detected' }
else {
  Write-Host 'could not detect QEMU/KVM virtual machine. Stopping deployment'
  throw 'no KVM/QEMU VM detected'
}

try {
  $app = Get-ItemProperty -Path @('HKLM:\Software\Wow6432Node\Microsoft\Windows\CurrentVersion\Uninstall\*',
				  'HKLM:\Software\Microsoft\Windows\CurrentVersion\Uninstall\*') `
    -ErrorAction:SilentlyContinue | Where-Object { $_.DisplayName -like $packageSearch }

  if ($app -and ([version]$app.DisplayVersion -ge [version]$version)) {
    Write-Host 'QEMU Guest Agent' $version 'or higher is already installed. Doing nothing.'
  } else {
    Install-ChocolateyPackage $packageName $installerType $silentArgs $url $url64 `
      -checksum $checksum -checksumType $checksumType `
      -checksum64 $checksum64 -checksumType64 $checksumType64 `
      -validExitCodes $validExitCodes
  }
} catch {
  throw $_.Exception
}
